<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Agradecimentos</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1238"/>
        <source>Version: %1</source>
        <translation>Versão: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1242"/>
        <source>%1 is released under %2</source>
        <translation>%1 é lançado sob %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
        <source>Black</source>
        <translation>Preto</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
        <source>White</source>
        <translation>Branco</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
        <source>Dark Gray</source>
        <translation>Cinzento Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
        <source>Gray</source>
        <translation>Cinzento</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
        <source>Light Gray</source>
        <translation>Cinzento Claro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
        <source>Red</source>
        <translation>Vermelho</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
        <source>Cyan</source>
        <translation>Ciano</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
        <source>Yellow</source>
        <translation>Amarelo</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
        <source>Dark Red</source>
        <translation>Vermelho Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
        <source>Dark Green</source>
        <translation>Verde Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
        <source>Dark Blue</source>
        <translation>Azul Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
        <source>Dark Cyan</source>
        <translation>Ciano Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
        <source>Dark Magenta</source>
        <translation>Magenta Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
        <source>Dark Yellow</source>
        <translation>Amarelo Escuro</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
        <source>Enter a new shortcut</source>
        <translation>Inserir um novo atalho</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="471"/>
        <source>Stop reading</source>
        <translation>Parar a leitura</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="473"/>
        <source>Text to Speech</source>
        <translation>Texto para Voz</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="496"/>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="518"/>
        <source>Speech To Text</source>
        <translation>Voz para Texto</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
        <source>Printer</source>
        <translation>Impressora</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Copies</source>
        <translation>Cópias</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
        <source>Page range</source>
        <translation>Intervalo de páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
        <source>All</source>
        <translation>Tudo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Current page</source>
        <translation>Pagina atual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
        <source>Select pages</source>
        <translation>Selecionar páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
        <source>Orientation</source>
        <translation>Orientação</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
        <source>Portrait</source>
        <translation>Retrato</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
        <source>Landscape</source>
        <translation>Paisagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
        <source>Pages</source>
        <translation>Páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
        <source>Color mode</source>
        <translation>Modo de cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Grayscale</source>
        <translation>Escala de cinzentos</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
        <source>Margins</source>
        <translation>Margens</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Narrow (mm)</source>
        <translation>Estreita (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Normal (mm)</source>
        <translation>Normal (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Moderate (mm)</source>
        <translation>Moderada (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Customize (mm)</source>
        <translation>Personalizada (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Scaling</source>
        <translation>Dimensionamento </translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
        <source>Actual size</source>
        <translation>Tamanho atual</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
        <source>Paper</source>
        <translation>Papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
        <source>Paper size</source>
        <translation>Tamanho do papel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
        <source>Print Layout</source>
        <translation>Esquema de impressão</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
        <source>Duplex</source>
        <translation>Frente e Verso</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
        <source>N-up printing</source>
        <translation>Impressão N-up</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 páginas/folha, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 páginas/folha, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 páginas/folha, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 páginas/folha, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 páginas/folha, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
        <source>Layout direction</source>
        <translation>Direção do esquema</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
        <source>Page Order</source>
        <translation>Ordem das páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Collate pages</source>
        <translation>Agrupar páginas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
        <source>Print pages in order</source>
        <translation>Imprimir páginas por ordem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Front to back</source>
        <translation>De frente para trás</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Back to front</source>
        <translation>De trás para a frente</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
        <source>Watermark</source>
        <translation>Marca d&apos;água</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
        <source>Add watermark</source>
        <translation>Adicionar marca d&apos;água</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Text watermark</source>
        <translation>Marca d&apos;água de texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Sample</source>
        <translation>Exemplo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Custom</source>
        <translation>Personalizada</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Input your text</source>
        <translation>Introduza o seu texto</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
        <source>Picture watermark</source>
        <translation>Marca d&apos;água de imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
        <source>Layout</source>
        <translation>Esquema</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Tile</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
        <source>Angle</source>
        <translation>Ângulo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
        <source>Transparency</source>
        <translation>Transparência</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
        <source>Print to PDF</source>
        <translation>Imprimir para PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
        <source>Save as Image</source>
        <translation>Guardar como imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
        <source>Collapse</source>
        <translation>Recolher</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
        <source>Flip on short edge</source>
        <translation>Virar na margem curta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <source>Flip on long edge</source>
        <translation>Virar na margem comprida</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>Introduza os números da página</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>Número máximo de páginas atingido</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>Introduza a vírgula inglesa</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Introduza números de páginas assim: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>*.pdf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Por exemplo, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>Save as PDF</source>
        <translation>Guardar como PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
        <source>Save as image</source>
        <translation>Guardar como imagem</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Confidencial</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Rascunho</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Exemplo</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="291"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Esse atalho entra em conflito com %1, clique em &quot;Adicionar&quot; para aplicar este atalho imediatamente</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Introduza um novo atalho</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="171"/>
        <source>Stop reading</source>
        <translation>Parar a leitura</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="173"/>
        <source>Text to Speech</source>
        <translation>Texto para Voz</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="196"/>
        <source>Translate</source>
        <translation>Traduzir</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="218"/>
        <source>Speech To Text</source>
        <translation>Voz para Texto</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
        <source>Color</source>
        <translation>Cor</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="454"/>
        <source>Select All</source>
        <translation>Selecionar tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1334"/>
        <source>No search result</source>
        <translation>Nenhum resultado da pesquisa</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="331"/>
        <source>Restore Defaults</source>
        <translation>Restaurar Predefinições</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="163"/>
        <source>Select All</source>
        <translation>Selecionar tudo</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Introduza um novo atalho</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="527"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="529"/>
        <source>Light Theme</source>
        <translation>Tema Claro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="530"/>
        <source>Dark Theme</source>
        <translation>Tema Escuro</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="531"/>
        <source>System Theme</source>
        <translation>Tema do Sistema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="555"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="563"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="570"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
</TS>